@@ -6,6 +6,7 @@
  * Copyright (C) 2013 - 2014 Aleksander Morgado <aleksander@aleksander.es>
  * Copyright (C) 2014 NVDIA Corporation
  * Copyright (C) 2014 Smith Micro Software, Inc.
+ * Copyright (C) 2022 Intel Corporation
  */
 
 #include <config.h>
@@ -256,6 +257,46 @@ static const MbimUuid uuid_ms_voice_extensions = {
     .e = { 0x61, 0xcb, 0x03, 0x4a, 0x70, 0x2e }
 };
 
+static const MbimUuid uuid_intel_mutual_authentication = {
+    .a = { 0xf8, 0x5d, 0x46, 0xef },
+    .b = { 0xab, 0x26 },
+    .c = { 0x40, 0x81 },
+    .d = { 0x98, 0x68 },
+    .e = { 0x4d, 0x18, 0x3c, 0x0a, 0x3a, 0xec }
+};
+
+static const MbimUuid uuid_intel_tools = {
+    .a = { 0x4a, 0xda, 0x49, 0x62 },
+    .b = { 0xb9, 0x88 },
+    .c = { 0x46, 0xc3 },
+    .d = { 0x87, 0xa7 },
+    .e = { 0x97, 0xf2, 0x0f, 0x99, 0x4a, 0xbb }
+};
+
+static const MbimUuid uuid_google = {
+    .a = { 0x3e, 0x1e, 0x92, 0xcf },
+    .b = { 0xc5, 0x3d },
+    .c = { 0x4f, 0x14 },
+    .d = { 0x85, 0xd0 },
+    .e = { 0xa8, 0x6a, 0xd9, 0xe1, 0x22, 0x45 }
+};
+
+static const MbimUuid uuid_fibocom = {
+    .a = { 0xff, 0xff, 0xff, 0xff },
+    .b = { 0xab, 0xca },
+    .c = { 0x4b, 0x11 },
+    .d = { 0xa4, 0xe2 },
+    .e = { 0xf2, 0xfc, 0x87, 0xf9, 0x44, 0x88 }
+};
+
+static const MbimUuid uuid_compal = {
+    .a = { 0xa2, 0xa3, 0x2a, 0x97 },
+    .b = { 0xca, 0xb1 },
+    .c = { 0x4f, 0x57 },
+    .d = { 0x9a, 0xe1 },
+    .e = { 0x45, 0x1c, 0x74, 0xdd, 0xa9, 0x57 }
+};
+
 static GList *mbim_custom_service_list = NULL;
 
 typedef struct {
@@ -391,6 +432,16 @@ mbim_uuid_from_service (MbimService service)
         return &uuid_intel_thermal_rf;
     case MBIM_SERVICE_MS_VOICE_EXTENSIONS:
         return &uuid_ms_voice_extensions;
+    case MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION:
+        return &uuid_intel_mutual_authentication;
+    case MBIM_SERVICE_INTEL_TOOLS:
+        return &uuid_intel_tools;
+    case MBIM_SERVICE_GOOGLE:
+        return &uuid_google;
+    case MBIM_SERVICE_FIBOCOM:
+        return &uuid_fibocom;
+    case MBIM_SERVICE_COMPAL:
+        return &uuid_compal;
     case MBIM_SERVICE_LAST:
         g_assert_not_reached ();
     default:
@@ -467,6 +518,21 @@ mbim_uuid_to_service (const MbimUuid *uuid)
     if (mbim_uuid_cmp (uuid, &uuid_ms_voice_extensions))
         return MBIM_SERVICE_MS_VOICE_EXTENSIONS;
 
+    if (mbim_uuid_cmp (uuid, &uuid_intel_mutual_authentication))
+        return MBIM_SERVICE_INTEL_MUTUAL_AUTHENTICATION;
+
+    if (mbim_uuid_cmp (uuid, &uuid_intel_tools))
+        return MBIM_SERVICE_INTEL_TOOLS;
+
+    if (mbim_uuid_cmp (uuid, &uuid_google))
+        return MBIM_SERVICE_GOOGLE;
+
+    if (mbim_uuid_cmp (uuid, &uuid_fibocom))
+        return MBIM_SERVICE_FIBOCOM;
+
+    if (mbim_uuid_cmp (uuid, &uuid_compal))
+        return MBIM_SERVICE_COMPAL;
+
     for (l = mbim_custom_service_list; l != NULL; l = l->next) {
         if (mbim_uuid_cmp (&((MbimCustomService *)l->data)->uuid, uuid))
             return ((MbimCustomService *)l->data)->service_id;
